
spongeshaker API
================

.. contents:: Table Of Contents


:mod:`spongeshaker.sha3` - SHA-3 proposal
-----------------------------------------

.. automodule:: spongeshaker.sha3
   :members:

:mod:`spongeshaker.hashing` - Sponge as hash
--------------------------------------------

.. automodule:: spongeshaker.hashing
   :members:

:mod:`spongeshaker.prng` - Sponge as PRNG
-----------------------------------------

.. automodule:: spongeshaker.prng
   :members:

:mod:`spongeshaker.stream_cipher` - Sponge as Stream cipher
-----------------------------------------------------------

.. automodule:: spongeshaker.stream_cipher
   :members:

:mod:`spongeshaker.spongewrap` - Sponge as AEAD cipher
------------------------------------------------------

.. automodule:: spongeshaker.spongewrap
   :members:

:mod:`spongeshaker.sponge` - Generic low-level sponge API
---------------------------------------------------------

.. automodule:: spongeshaker.sponge
   :members:

:mod:`spongeshaker.keccak` - Low-level sponge API for Keccak
------------------------------------------------------------

.. automodule:: spongeshaker.keccak
   :members:

